project

# XMLRésuméLibrary: User Guide

present | Element Reference | projects

## Name

project — Container for information about a project

## Synopsis

### Content Model

    (#PCDATA|emphasis|citation|url|link)*

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None
title | CDATA | None

## Description

The `project` element describes a project that a person participated in at a `job`.

### Parents

`project` may be contained in these elements: `projects`

### Attributes

`title`

  The title of the project.

## See Also

`achievement`.

## Examples

For examples, see `projects`.

present | Element Reference | projects